#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['bapy']

package_data = \
{'': ['*'], 'bapy': ['data/*', 'scripts/*']}

install_requires = \
['decorator',
 'devtools',
 'distro',
 'dpath',
 'icecream',
 'environs',
 'furl',
 'gitpython',
 'inflect',
 'intervaltree',
 'jinja2',
 'jsonpickle',
 'loguru',
 'marshmallow',
 'more_itertools',
 'motor',
 'nested_lookup',
 'paramiko',
 'pip',
 'pymongo[srv,tls]',
 'python-box',
 'requests[security]',
 'rich',
 'semver',
 'setuptools',
 'structlog',
 'typer[all]',
 'wheel']

entry_points = \
{'console_scripts': ['bapy = bapy:app', 'localbin = bapy:localbin']}

setup(name='bapy',
      version='1.0.40',
      description='Bapy Package.',
      author='José',
      author_email=None,
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
     )
